@@ -4,7 +4,7 @@ from PyQt5 import QtCore, QtGui, QtWidgets
 class Ui_SettingsDialog(object):
     def setupUi(self, SettingsDialog):
         SettingsDialog.setObjectName("SettingsDialog")
-        SettingsDialog.resize(440, 481)
+        SettingsDialog.resize(442, 541)
         self.lay_main = QtWidgets.QVBoxLayout(SettingsDialog)
         self.lay_main.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
         self.lay_main.setObjectName("lay_main")
@@ -12,51 +12,59 @@ class Ui_SettingsDialog(object):
         self.lay_body.setObjectName("lay_body")
         self.lay_left_column = QtWidgets.QVBoxLayout()
         self.lay_left_column.setObjectName("lay_left_column")
+        self.lay_section_player = QtWidgets.QVBoxLayout()
+        self.lay_section_player.setObjectName("lay_section_player")
         self.section_player = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
         font.setWeight(75)
         self.section_player.setFont(font)
         self.section_player.setObjectName("section_player")
-        self.lay_left_column.addWidget(self.section_player)
+        self.lay_section_player.addWidget(self.section_player)
         self.playerPauseBackgroundVideos = QtWidgets.QCheckBox(SettingsDialog)
         self.playerPauseBackgroundVideos.setObjectName("playerPauseBackgroundVideos")
-        self.lay_left_column.addWidget(self.playerPauseBackgroundVideos)
+        self.lay_section_player.addWidget(self.playerPauseBackgroundVideos)
         self.playerPauseWhenMinimized = QtWidgets.QCheckBox(SettingsDialog)
         self.playerPauseWhenMinimized.setObjectName("playerPauseWhenMinimized")
-        self.lay_left_column.addWidget(self.playerPauseWhenMinimized)
+        self.lay_section_player.addWidget(self.playerPauseWhenMinimized)
         self.playerInhibitScreensaver = QtWidgets.QCheckBox(SettingsDialog)
         self.playerInhibitScreensaver.setObjectName("playerInhibitScreensaver")
-        self.lay_left_column.addWidget(self.playerInhibitScreensaver)
+        self.lay_section_player.addWidget(self.playerInhibitScreensaver)
         self.playerOneInstance = QtWidgets.QCheckBox(SettingsDialog)
         self.playerOneInstance.setObjectName("playerOneInstance")
-        self.lay_left_column.addWidget(self.playerOneInstance)
+        self.lay_section_player.addWidget(self.playerOneInstance)
+        self.lay_left_column.addLayout(self.lay_section_player)
+        self.lay_section_playlist = QtWidgets.QVBoxLayout()
+        self.lay_section_playlist.setObjectName("lay_section_playlist")
         self.section_playlist = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
         font.setWeight(75)
         self.section_playlist.setFont(font)
         self.section_playlist.setObjectName("section_playlist")
-        self.lay_left_column.addWidget(self.section_playlist)
+        self.lay_section_playlist.addWidget(self.section_playlist)
         self.playlistSaveWindow = QtWidgets.QCheckBox(SettingsDialog)
         self.playlistSaveWindow.setObjectName("playlistSaveWindow")
-        self.lay_left_column.addWidget(self.playlistSaveWindow)
+        self.lay_section_playlist.addWidget(self.playlistSaveWindow)
         self.playlistSavePosition = QtWidgets.QCheckBox(SettingsDialog)
         self.playlistSavePosition.setObjectName("playlistSavePosition")
-        self.lay_left_column.addWidget(self.playlistSavePosition)
+        self.lay_section_playlist.addWidget(self.playlistSavePosition)
         self.playlistSaveState = QtWidgets.QCheckBox(SettingsDialog)
         self.playlistSaveState.setObjectName("playlistSaveState")
-        self.lay_left_column.addWidget(self.playlistSaveState)
+        self.lay_section_playlist.addWidget(self.playlistSaveState)
         self.playlistSeekSync = QtWidgets.QCheckBox(SettingsDialog)
         self.playlistSeekSync.setObjectName("playlistSeekSync")
-        self.lay_left_column.addWidget(self.playlistSeekSync)
+        self.lay_section_playlist.addWidget(self.playlistSeekSync)
+        self.lay_left_column.addLayout(self.lay_section_playlist)
+        self.lay_section_grid = QtWidgets.QVBoxLayout()
+        self.lay_section_grid.setObjectName("lay_section_grid")
         self.section_grid = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
         font.setWeight(75)
         self.section_grid.setFont(font)
         self.section_grid.setObjectName("section_grid")
-        self.lay_left_column.addWidget(self.section_grid)
+        self.lay_section_grid.addWidget(self.section_grid)
         self.lay_gridMode = QtWidgets.QHBoxLayout()
         self.lay_gridMode.setObjectName("lay_gridMode")
         self.gridModeLabel = QtWidgets.QLabel(SettingsDialog)
@@ -69,7 +77,7 @@ class Ui_SettingsDialog(object):
             40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
         )
         self.lay_gridMode.addItem(spacerItem)
-        self.lay_left_column.addLayout(self.lay_gridMode)
+        self.lay_section_grid.addLayout(self.lay_gridMode)
         self.lay_gridSize = QtWidgets.QHBoxLayout()
         self.lay_gridSize.setObjectName("lay_gridSize")
         self.gridSize = QtWidgets.QSpinBox(SettingsDialog)
@@ -78,18 +86,24 @@ class Ui_SettingsDialog(object):
         self.gridSizeLabel = QtWidgets.QLabel(SettingsDialog)
         self.gridSizeLabel.setObjectName("gridSizeLabel")
         self.lay_gridSize.addWidget(self.gridSizeLabel)
-        self.lay_gridSize.setStretch(1, 1)
-        self.lay_left_column.addLayout(self.lay_gridSize)
+        spacerItem1 = QtWidgets.QSpacerItem(
+            40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
+        )
+        self.lay_gridSize.addItem(spacerItem1)
+        self.lay_section_grid.addLayout(self.lay_gridSize)
         self.gridFit = QtWidgets.QCheckBox(SettingsDialog)
         self.gridFit.setObjectName("gridFit")
-        self.lay_left_column.addWidget(self.gridFit)
+        self.lay_section_grid.addWidget(self.gridFit)
+        self.lay_left_column.addLayout(self.lay_section_grid)
+        self.lay_section_video_defaults = QtWidgets.QVBoxLayout()
+        self.lay_section_video_defaults.setObjectName("lay_section_video_defaults")
         self.section_video_defaults = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
         font.setWeight(75)
         self.section_video_defaults.setFont(font)
         self.section_video_defaults.setObjectName("section_video_defaults")
-        self.lay_left_column.addWidget(self.section_video_defaults)
+        self.lay_section_video_defaults.addWidget(self.section_video_defaults)
         self.lay_aspect = QtWidgets.QHBoxLayout()
         self.lay_aspect.setObjectName("lay_aspect")
         self.videoAspectLabel = QtWidgets.QLabel(SettingsDialog)
@@ -98,27 +112,49 @@ class Ui_SettingsDialog(object):
         self.videoAspect = QtWidgets.QComboBox(SettingsDialog)
         self.videoAspect.setObjectName("videoAspect")
         self.lay_aspect.addWidget(self.videoAspect)
-        spacerItem1 = QtWidgets.QSpacerItem(
+        spacerItem2 = QtWidgets.QSpacerItem(
             40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
         )
-        self.lay_aspect.addItem(spacerItem1)
-        self.lay_left_column.addLayout(self.lay_aspect)
+        self.lay_aspect.addItem(spacerItem2)
+        self.lay_section_video_defaults.addLayout(self.lay_aspect)
+        self.lay_repeat = QtWidgets.QHBoxLayout()
+        self.lay_repeat.setObjectName("lay_repeat")
+        self.repeatModeLabel = QtWidgets.QLabel(SettingsDialog)
+        self.repeatModeLabel.setObjectName("repeatModeLabel")
+        self.lay_repeat.addWidget(self.repeatModeLabel)
+        self.repeatMode = QtWidgets.QComboBox(SettingsDialog)
+        self.repeatMode.setObjectName("repeatMode")
+        self.lay_repeat.addWidget(self.repeatMode)
+        spacerItem3 = QtWidgets.QSpacerItem(
+            40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum
+        )
+        self.lay_repeat.addItem(spacerItem3)
+        self.lay_section_video_defaults.addLayout(self.lay_repeat)
         self.videoRandomLoop = QtWidgets.QCheckBox(SettingsDialog)
         self.videoRandomLoop.setObjectName("videoRandomLoop")
-        self.lay_left_column.addWidget(self.videoRandomLoop)
+        self.lay_section_video_defaults.addWidget(self.videoRandomLoop)
         self.videoPaused = QtWidgets.QCheckBox(SettingsDialog)
         self.videoPaused.setObjectName("videoPaused")
-        self.lay_left_column.addWidget(self.videoPaused)
+        self.lay_section_video_defaults.addWidget(self.videoPaused)
         self.videoMuted = QtWidgets.QCheckBox(SettingsDialog)
         self.videoMuted.setObjectName("videoMuted")
-        self.lay_left_column.addWidget(self.videoMuted)
-        spacerItem2 = QtWidgets.QSpacerItem(
+        self.lay_section_video_defaults.addWidget(self.videoMuted)
+        self.lay_left_column.addLayout(self.lay_section_video_defaults)
+        spacerItem4 = QtWidgets.QSpacerItem(
             0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
         )
-        self.lay_left_column.addItem(spacerItem2)
+        self.lay_left_column.addItem(spacerItem4)
         self.lay_body.addLayout(self.lay_left_column)
         self.lay_right_column = QtWidgets.QVBoxLayout()
         self.lay_right_column.setObjectName("lay_right_column")
+        self.languageBox = QtWidgets.QGroupBox(SettingsDialog)
+        self.languageBox.setObjectName("languageBox")
+        self.verticalLayout = QtWidgets.QVBoxLayout(self.languageBox)
+        self.verticalLayout.setObjectName("verticalLayout")
+        self.language = QtWidgets.QComboBox(self.languageBox)
+        self.language.setObjectName("language")
+        self.verticalLayout.addWidget(self.language)
+        self.lay_right_column.addWidget(self.languageBox)
         self.playerVideoDriverBox = QtWidgets.QGroupBox(SettingsDialog)
         self.playerVideoDriverBox.setObjectName("playerVideoDriverBox")
         self.lay_playerVideoDriverBox = QtWidgets.QVBoxLayout(self.playerVideoDriverBox)
@@ -139,13 +175,18 @@ class Ui_SettingsDialog(object):
         self.lay_playerVideoDriverPlayers.setStretch(0, 1)
         self.lay_playerVideoDriverBox.addLayout(self.lay_playerVideoDriverPlayers)
         self.lay_right_column.addWidget(self.playerVideoDriverBox)
+        self.lay_section_timeouts = QtWidgets.QVBoxLayout()
+        self.lay_section_timeouts.setObjectName("lay_section_timeouts")
         self.section_timeouts = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
         font.setWeight(75)
         self.section_timeouts.setFont(font)
         self.section_timeouts.setObjectName("section_timeouts")
-        self.lay_right_column.addWidget(self.section_timeouts)
+        self.lay_section_timeouts.addWidget(self.section_timeouts)
+        self.timeoutOverlayFlag = QtWidgets.QCheckBox(SettingsDialog)
+        self.timeoutOverlayFlag.setObjectName("timeoutOverlayFlag")
+        self.lay_section_timeouts.addWidget(self.timeoutOverlayFlag)
         self.lay_timeoutOverlay = QtWidgets.QHBoxLayout()
         self.lay_timeoutOverlay.setObjectName("lay_timeoutOverlay")
         self.timeoutOverlay = QtWidgets.QSpinBox(SettingsDialog)
@@ -155,10 +196,10 @@ class Ui_SettingsDialog(object):
         self.timeoutOverlayLabel.setObjectName("timeoutOverlayLabel")
         self.lay_timeoutOverlay.addWidget(self.timeoutOverlayLabel)
         self.lay_timeoutOverlay.setStretch(1, 1)
-        self.lay_right_column.addLayout(self.lay_timeoutOverlay)
+        self.lay_section_timeouts.addLayout(self.lay_timeoutOverlay)
         self.timeoutMouseHideFlag = QtWidgets.QCheckBox(SettingsDialog)
         self.timeoutMouseHideFlag.setObjectName("timeoutMouseHideFlag")
-        self.lay_right_column.addWidget(self.timeoutMouseHideFlag)
+        self.lay_section_timeouts.addWidget(self.timeoutMouseHideFlag)
         self.lay_timeoutMouseHide = QtWidgets.QHBoxLayout()
         self.lay_timeoutMouseHide.setObjectName("lay_timeoutMouseHide")
         self.timeoutMouseHide = QtWidgets.QSpinBox(SettingsDialog)
@@ -168,14 +209,17 @@ class Ui_SettingsDialog(object):
         self.timeoutMouseHideLabel.setObjectName("timeoutMouseHideLabel")
         self.lay_timeoutMouseHide.addWidget(self.timeoutMouseHideLabel)
         self.lay_timeoutMouseHide.setStretch(1, 1)
-        self.lay_right_column.addLayout(self.lay_timeoutMouseHide)
+        self.lay_section_timeouts.addLayout(self.lay_timeoutMouseHide)
+        self.lay_right_column.addLayout(self.lay_section_timeouts)
+        self.lay_section_logging = QtWidgets.QVBoxLayout()
+        self.lay_section_logging.setObjectName("lay_section_logging")
         self.section_logging = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
         font.setWeight(75)
         self.section_logging.setFont(font)
         self.section_logging.setObjectName("section_logging")
-        self.lay_right_column.addWidget(self.section_logging)
+        self.lay_section_logging.addWidget(self.section_logging)
         self.lay_logLevel = QtWidgets.QHBoxLayout()
         self.lay_logLevel.setObjectName("lay_logLevel")
         self.logLevelLabel = QtWidgets.QLabel(SettingsDialog)
@@ -184,7 +228,7 @@ class Ui_SettingsDialog(object):
         self.logLevel = QtWidgets.QComboBox(SettingsDialog)
         self.logLevel.setObjectName("logLevel")
         self.lay_logLevel.addWidget(self.logLevel)
-        self.lay_right_column.addLayout(self.lay_logLevel)
+        self.lay_section_logging.addLayout(self.lay_logLevel)
         self.lay_logLevelVLC = QtWidgets.QHBoxLayout()
         self.lay_logLevelVLC.setObjectName("lay_logLevelVLC")
         self.logLevelVLCLabel = QtWidgets.QLabel(SettingsDialog)
@@ -193,7 +237,8 @@ class Ui_SettingsDialog(object):
         self.logLevelVLC = QtWidgets.QComboBox(SettingsDialog)
         self.logLevelVLC.setObjectName("logLevelVLC")
         self.lay_logLevelVLC.addWidget(self.logLevelVLC)
-        self.lay_right_column.addLayout(self.lay_logLevelVLC)
+        self.lay_section_logging.addLayout(self.lay_logLevelVLC)
+        self.lay_right_column.addLayout(self.lay_section_logging)
         self.section_misc = QtWidgets.QLabel(SettingsDialog)
         font = QtGui.QFont()
         font.setBold(True)
@@ -204,10 +249,13 @@ class Ui_SettingsDialog(object):
         self.miscOpaqueHWOverlay = QtWidgets.QCheckBox(SettingsDialog)
         self.miscOpaqueHWOverlay.setObjectName("miscOpaqueHWOverlay")
         self.lay_right_column.addWidget(self.miscOpaqueHWOverlay)
-        spacerItem3 = QtWidgets.QSpacerItem(
+        self.lay_section_misc = QtWidgets.QVBoxLayout()
+        self.lay_section_misc.setObjectName("lay_section_misc")
+        self.lay_right_column.addLayout(self.lay_section_misc)
+        spacerItem5 = QtWidgets.QSpacerItem(
             0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding
         )
-        self.lay_right_column.addItem(spacerItem3)
+        self.lay_right_column.addItem(spacerItem5)
         self.lay_body.addLayout(self.lay_right_column)
         self.lay_body.setStretch(0, 1)
         self.lay_main.addLayout(self.lay_body)
@@ -253,13 +301,13 @@ class Ui_SettingsDialog(object):
             _translate("SettingsDialog", "Save window position and size")
         )
         self.playlistSavePosition.setText(
-            _translate("SettingsDialog", "Save videos position")
+            _translate("SettingsDialog", "Save videos playback position")
         )
         self.playlistSaveState.setText(
             _translate("SettingsDialog", "Save videos playing / paused status")
         )
         self.playlistSeekSync.setText(
-            _translate("SettingsDialog", "Seek in sync by default")
+            _translate("SettingsDialog", "Synchronize seek by default")
         )
         self.section_grid.setText(
             _translate("SettingsDialog", "Default Grid Parameters")
@@ -271,11 +319,13 @@ class Ui_SettingsDialog(object):
             _translate("SettingsDialog", "Default Video Parameters")
         )
         self.videoAspectLabel.setText(_translate("SettingsDialog", "Aspect mode"))
+        self.repeatModeLabel.setText(_translate("SettingsDialog", "Repeat mode"))
         self.videoRandomLoop.setText(
             _translate("SettingsDialog", "Start at random position")
         )
         self.videoPaused.setText(_translate("SettingsDialog", "Paused"))
         self.videoMuted.setText(_translate("SettingsDialog", "Muted"))
+        self.languageBox.setTitle(_translate("SettingsDialog", "Language"))
         self.playerVideoDriverBox.setTitle(
             _translate("SettingsDialog", "Video Decoder")
         )
@@ -283,6 +333,9 @@ class Ui_SettingsDialog(object):
             _translate("SettingsDialog", "Videos per process")
         )
         self.section_timeouts.setText(_translate("SettingsDialog", "Timeouts"))
+        self.timeoutOverlayFlag.setText(
+            _translate("SettingsDialog", "Hide overlay after timeout")
+        )
         self.timeoutOverlayLabel.setText(
             _translate("SettingsDialog", "Video overlay timeout (sec)")
         )
