@@ -1,4 +1,3 @@
-import os
 import sys
 
 from PyQt5.QtCore import qInstallMessageHandler
@@ -11,7 +10,7 @@ from gridplayer.version import __app_name__
 
 
 def init_log():
-    log_path = os.path.join(get_app_data_dir(), f"{__app_name__.lower()}.log")
+    log_path = get_app_data_dir() / f"{__app_name__.lower()}.log"
 
     log_config.config_log(log_path, Settings().get("logging/log_level"))
     log_config.override_stdout()
