@@ -1,29 +1,24 @@
-import os
 import random
 import secrets
+from pathlib import Path
+from typing import Optional
 
-from PyQt5.QtCore import QSize, Qt, QTimer, pyqtSignal
-from PyQt5.QtGui import QCursor, QIcon
-from PyQt5.QtWidgets import QGraphicsOpacityEffect, QLabel, QStackedLayout, QWidget
+from pydantic.color import Color
+from PyQt5.QtCore import Qt, QTimer, pyqtSignal
+from PyQt5.QtGui import QCursor
+from PyQt5.QtWidgets import QStackedLayout, QWidget
 
+from gridplayer.dialogs.rename_dialog import QVideoRenameDialog
 from gridplayer.exceptions import PlayerException
-from gridplayer.params_static import PLAYER_ID_LENGTH
+from gridplayer.params_static import PLAYER_ID_LENGTH, VideoRepeat
 from gridplayer.settings import Settings
 from gridplayer.utils.misc import qt_connect
-from gridplayer.video import MAX_RATE, MAX_SCALE, MIN_RATE, MIN_SCALE
+from gridplayer.utils.next_file import next_video_file
+from gridplayer.video import MAX_RATE, MAX_SCALE, MIN_RATE, MIN_SCALE, Video
+from gridplayer.widgets.video_block_status import StatusLabel
 from gridplayer.widgets.video_overlay import OverlayBlock, OverlayBlockFloating
 
 
-def only_initialized(func):
-    def wrapper(self, *args, **kwargs):
-        if not self.video_driver.is_video_initialized:
-            return None
-
-        return func(self, *args, **kwargs)
-
-    return wrapper
-
-
 class QStackedLayoutFloating(QStackedLayout):
     """overridden setGeometry for children is not honored due to type casting inside Qt,
     need to override setGeometry in Layout to make floating windows resize with parent
@@ -43,49 +38,8 @@ class QStackedLayoutFloating(QStackedLayout):
                     widget.setGeometry(rect)
 
 
-class StatusLabel(QLabel):
-    def __init__(self, **kwargs):
-        super().__init__(**kwargs)
-
-        self.setAutoFillBackground(True)
-
-        # Due to Qt video block glitch, cannot hide video block
-        # workaround - make overlay loading screen 99% opaque
-        # so it will appear visually solid while video block is invisible
-        effect = QGraphicsOpacityEffect(self)
-        almost_opaque = 0.99
-        effect.setOpacity(almost_opaque)
-        self.setGraphicsEffect(effect)
-
-        self.setAlignment(Qt.AlignCenter)
-
-        self._set_pic(QIcon.fromTheme("processing"))
-
-    def resizeEvent(self, event):
-        self._set_pic_to_half_size(event.size())
-
-    def set_error(self):
-        self._set_pic(QIcon.fromTheme("close"))
-
-    def _set_pic(self, pic_path):
-        reasonably_big = 512
-        self.pic = QIcon(pic_path).pixmap(QSize(reasonably_big, reasonably_big))
-
-        self._set_pic_to_half_size(self.size())
-
-    def _set_pic_to_half_size(self, size):
-        half_size_multiplier = 0.75
-
-        width = int(size.width() * half_size_multiplier)
-        height = int(size.height() * half_size_multiplier)
-
-        self.setPixmap(
-            self.pic.scaled(width, height, Qt.KeepAspectRatio, Qt.SmoothTransformation)
-        )
-
-
 class VideoBlock(QWidget):  # noqa: WPS230
-    load_video = pyqtSignal(str)
+    load_video = pyqtSignal(Path)
 
     exit_request = pyqtSignal(str)
     percent_changed = pyqtSignal(float)
@@ -93,6 +47,7 @@ class VideoBlock(QWidget):  # noqa: WPS230
     time_change = pyqtSignal(int, int)
     volume_change = pyqtSignal(float)
     label_change = pyqtSignal(str)
+    color_change = pyqtSignal(str)
     loop_start_change = pyqtSignal(float)
     loop_end_change = pyqtSignal(float)
     is_paused_change = pyqtSignal(bool)
@@ -103,11 +58,11 @@ class VideoBlock(QWidget):  # noqa: WPS230
         super().__init__(**kwargs)
 
         # Internal
-        self.video_driver = video_driver(parent=self)
+        self.video_driver_cls = video_driver
         self.id = secrets.token_hex(PLAYER_ID_LENGTH)
 
         # Static Params
-        self.video_params = None
+        self.video_params: Optional[Video] = None
 
         # Dynamic Params
         self.is_active = False
@@ -117,9 +72,8 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.overlay_hide_timer.setSingleShot(True)
         self.overlay_hide_timer.timeout.connect(self.hide_overlay)
 
-        self.ui_video_driver()
-
-        self.ui_overlay()
+        self.video_driver = self.init_video_driver()
+        self.overlay = self.init_overlay()
 
         self.ui_setup()
 
@@ -127,39 +81,57 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.overlay.raise_()
         self.overlay.hide()
 
-    def ui_video_driver(self):
+    def init_video_driver(self):
+        video_driver = self.video_driver_cls(parent=self)
+
         qt_connect(
-            (self.video_driver.video_ready, self.load_video_finish),
-            (self.video_driver.time_changed, self.time_changed),
-            (self.video_driver.error, self.error),
-            (self.video_driver.crash, self.crash),
-            (self.load_video, self.video_driver.load_video),
+            (video_driver.video_ready, self.load_video_finish),
+            (video_driver.time_changed, self.time_changed),
+            (video_driver.error, self.error),
+            (video_driver.crash, self.crash),
+            (self.load_video, video_driver.load_video),
         )
 
-    def ui_overlay(self):
+        return video_driver
+
+    def reset_video_driver(self):
+        self.video_driver.video_ready.disconnect()
+        self.video_driver.time_changed.disconnect()
+        self.video_driver.error.disconnect()
+        self.video_driver.crash.disconnect()
+        self.load_video.disconnect()
+
+        self.layout_main.takeAt(1).widget()
+        self.video_driver = self.init_video_driver()
+        self.layout_main.insertWidget(1, self.video_driver)
+
+    def init_overlay(self):
         if self.video_driver.is_opengl:
-            self.overlay = OverlayBlockFloating(self)
-            self.installEventFilter(self.overlay)
+            overlay = OverlayBlockFloating(self)
+            self.installEventFilter(overlay)
         else:
-            self.overlay = OverlayBlock(self)
+            overlay = OverlayBlock(self)
 
         qt_connect(
-            (self.overlay.set_vid_pos, self.seek_percent),
-            (self.overlay.set_vid_pos, self.percent_changed),
-            (self.overlay.set_volume, self.set_volume),
-            (self.overlay.exit_clicked, self.exit),
-            (self.overlay.play_pause_clicked, self.play_pause),
-            (self.overlay.mute_unmute_clicked, self.mute_unmute),
-            (self.time_change, self.overlay.set_position),
-            (self.volume_change, self.overlay.set_volume_position),
-            (self.label_change, self.overlay.set_label),
-            (self.loop_start_change, self.overlay.set_loop_start),
-            (self.loop_end_change, self.overlay.set_loop_end),
-            (self.is_paused_change, self.overlay.set_is_paused),
-            (self.is_muted_change, self.overlay.set_is_muted),
-            (self.info_change, self.overlay.set_info_label),
+            (overlay.set_vid_pos, self.seek_percent),
+            (overlay.set_vid_pos, self.percent_changed),
+            (overlay.set_volume, self.set_volume),
+            (overlay.exit_clicked, self.exit),
+            (overlay.play_pause_clicked, self.play_pause),
+            (overlay.mute_unmute_clicked, self.mute_unmute),
+            (self.time_change, overlay.set_position),
+            (self.volume_change, overlay.set_volume_position),
+            (self.label_change, overlay.set_label),
+            (self.color_change, overlay.set_color),
+            (self.loop_start_change, overlay.set_loop_start),
+            (self.loop_end_change, overlay.set_loop_end),
+            (self.is_paused_change, overlay.set_is_paused),
+            (self.is_muted_change, overlay.set_is_muted),
+            (self.info_change, overlay.set_info_label),
         )
 
+        return overlay
+
     def ui_setup(self):
         self.setMouseTracking(True)
 
@@ -197,9 +169,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.video_driver.cleanup()
 
-        self.status_label.hide()
-        self.repaint()
-
     def error(self):
         self.video_driver.is_video_initialized = False
         self.is_error = True
@@ -215,6 +184,10 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.exit_request.emit(self.id)
 
     def wheelEvent(self, event):
+        if not self.is_video_initialized:
+            event.ignore()
+            return
+
         is_shift_forward = event.angleDelta().y() < 0
         is_big_shift = event.modifiers() & Qt.ShiftModifier
 
@@ -230,6 +203,10 @@ class VideoBlock(QWidget):  # noqa: WPS230
         event.ignore()
 
     def mouseReleaseEvent(self, event) -> None:
+        if not self.is_video_initialized:
+            event.ignore()
+            return
+
         if event.button() == Qt.LeftButton:
             self.play_pause()
 
@@ -238,9 +215,20 @@ class VideoBlock(QWidget):  # noqa: WPS230
     def hideEvent(self, event):
         self.hide_overlay()
 
+    def showEvent(self, event):
+        if self.is_video_initialized and not Settings().get("misc/overlay_hide"):
+            self.show_overlay()
+
     def is_under_cursor(self):
         return self.rect().contains(self.mapFromGlobal(QCursor.pos()))
 
+    @property
+    def is_video_initialized(self):
+        if self.video_driver is None:
+            return False
+
+        return self.video_driver.is_video_initialized
+
     @property
     def time(self):
         return self.video_params.current_position
@@ -272,22 +260,25 @@ class VideoBlock(QWidget):  # noqa: WPS230
             return self.video_driver.length - before_end_gap
         return self.video_params.loop_end
 
-    @only_initialized
     def show_overlay(self):
         self.overlay.show()
-        self.overlay_hide_timer.start(1000 * Settings().get("misc/overlay_timeout"))
+        if Settings().get("misc/overlay_hide"):
+            self.overlay_hide_timer.start(1000 * Settings().get("misc/overlay_timeout"))
 
     def hide_overlay(self):
+        if not Settings().get("misc/overlay_hide"):
+            return
+
         if self.is_active:
-            self.overlay_hide_timer.start(
-                1000 * Settings().get("misc/overlay_timeout"),
-            )
+            self.overlay_hide_timer.start(1000 * Settings().get("misc/overlay_timeout"))
             return
 
         self.overlay.hide()
 
-    @only_initialized
     def time_changed(self, new_time):
+        if not self.is_video_initialized:
+            return
+
         self.time = new_time
 
         # 100ms headspace for slow callbacks
@@ -295,18 +286,36 @@ class VideoBlock(QWidget):  # noqa: WPS230
             self.seek(self.loop_start)
 
         elif self.time > self.loop_end:
+            self.loop_end_action()
+
+    def loop_end_action(self):
+        is_single_file = self.video_params.repeat_mode == VideoRepeat.SINGLE_FILE
+
+        if self.video_params.loop_end is not None or is_single_file:
             if self.video_params.is_start_random:
                 self.seek_random()
             else:
                 self.seek(self.loop_start)
+        elif self.video_params.repeat_mode == VideoRepeat.DIR:
+            self.next_video()
+        elif self.video_params.repeat_mode == VideoRepeat.DIR_SHUFFLE:
+            self.shuffle_video()
+
+    def set_video(self, video_params: Video):
+        is_first_video = self.video_params is None
 
-    def set_video(self, video_params):
         self.video_params = video_params
 
+        # Shut down current video
+        if not is_first_video:
+            self.cleanup()
+            self.reset_video_driver()
+
         self.load_video.emit(self.video_params.file_path)
 
     def load_video_finish(self):  # noqa: WPS213
-        self.label_change.emit(os.path.basename(self.video_params.file_path))
+        self.label_change.emit(self.video_params.title)
+        self.color_change.emit(self.video_params.color.as_hex())
 
         self.video_driver.set_aspect_ratio(self.video_params.aspect_mode)
         self.video_driver.set_scale(self.video_params.scale)
@@ -330,22 +339,19 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.set_pause(self.video_params.is_paused)
 
         self.status_label.hide()
+        self.show_overlay()
 
-    @only_initialized
     def set_aspect(self, aspect):
         self.video_params.aspect_mode = aspect
 
         self.video_driver.set_aspect_ratio(self.video_params.aspect_mode)
 
-    @only_initialized
     def toggle_loop_random(self):
         self.video_params.is_start_random = not self.video_params.is_start_random
 
-    @only_initialized
     def set_loop_start(self):
         self.set_loop_start_time(self.time)
 
-    @only_initialized
     def set_loop_start_time(self, new_time):
         if new_time == self.video_params.loop_end:
             return
@@ -354,11 +360,9 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.loop_start_change.emit(new_time / self.video_driver.length)
 
-    @only_initialized
     def set_loop_end(self):
         self.set_loop_end_time(self.time)
 
-    @only_initialized
     def set_loop_end_time(self, new_time):
         if new_time == self.video_params.loop_start:
             return
@@ -367,7 +371,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.loop_end_change.emit(new_time / self.video_driver.length)
 
-    @only_initialized
     def reset_loop(self):
         self.video_params.loop_start = None
         self.video_params.loop_end = None
@@ -375,13 +378,14 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.loop_start_change.emit(0)
         self.loop_end_change.emit(100.0)
 
-    @only_initialized
+    def set_repeat_mode(self, repeat_mode: VideoRepeat):
+        self.video_params.repeat_mode = repeat_mode
+
     def seek_shift_percent(self, shift_percent):
         seek_ms = int(shift_percent / 100 * self.video_driver.length)
 
         self.seek_shift(seek_ms)
 
-    @only_initialized
     def seek_shift(self, seek_ms):
         seek_stretch = self.loop_end - self.loop_start
 
@@ -406,19 +410,16 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.seek(new_time)
 
-    @only_initialized
     def seek_random(self):
         random_ms = random.randint(self.loop_start, self.loop_end)  # noqa: S311
 
         self.seek(random_ms)
 
-    @only_initialized
     def seek_percent(self, percent):
         seek_ms = int(percent * self.video_driver.length)
 
         self.seek(seek_ms)
 
-    @only_initialized
     def seek(self, seek_ms):
         if seek_ms < self.loop_start or seek_ms > self.loop_end:
             seek_ms = self.loop_start
@@ -426,7 +427,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.video_driver.set_time(seek_ms)
         self.time = seek_ms
 
-    @only_initialized
     def step_frame(self, frames):
         if not self.video_params.is_paused:
             self.set_pause(True)
@@ -435,7 +435,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.seek_shift(ms_per_frame * frames)
 
-    @only_initialized
     def scale_increase(self):
         self.video_params.scale += 0.1
         self.video_params.scale = round(self.video_params.scale, 1)
@@ -448,7 +447,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.video_driver.set_scale(self.video_params.scale)
         self.info_change.emit("Zoom: {0}".format(self.video_params.scale))
 
-    @only_initialized
     def scale_decrease(self):
         self.video_params.scale -= 0.1
         self.video_params.scale = round(self.video_params.scale, 1)
@@ -461,14 +459,12 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.video_driver.set_scale(self.video_params.scale)
         self.info_change.emit("Zoom: {0}".format(self.video_params.scale))
 
-    @only_initialized
     def scale_reset(self):
         self.video_params.scale = 1.0
 
         self.video_driver.set_scale(self.video_params.scale)
         self.info_change.emit("Zoom: {0}".format(self.video_params.scale))
 
-    @only_initialized
     def rate_increase(self):
         self.video_params.rate += 0.1
         self.video_params.rate = round(self.video_params.rate, 1)
@@ -481,7 +477,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.video_driver.set_playback_rate(self.video_params.rate)
         self.info_change.emit("Speed: {0}".format(self.video_params.rate))
 
-    @only_initialized
     def rate_decrease(self):
         self.video_params.rate -= 0.1
         self.video_params.rate = round(self.video_params.rate, 1)
@@ -494,14 +489,12 @@ class VideoBlock(QWidget):  # noqa: WPS230
         self.video_driver.set_playback_rate(self.video_params.rate)
         self.info_change.emit("Speed: {0}".format(self.video_params.rate))
 
-    @only_initialized
     def rate_reset(self):
         self.video_params.rate = 1.0
 
         self.video_driver.set_playback_rate(self.video_params.rate)
         self.info_change.emit("Speed: {0}".format(self.video_params.rate))
 
-    @only_initialized
     def set_pause(self, paused):
         self.video_params.is_paused = paused
 
@@ -512,11 +505,9 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.is_paused_change.emit(self.video_params.is_paused)
 
-    @only_initialized
     def mute_unmute(self):
         self.set_muted(not self.video_params.is_muted)
 
-    @only_initialized
     def set_muted(self, muted):
         self.video_params.is_muted = muted
 
@@ -524,7 +515,6 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.is_muted_change.emit(self.video_params.is_muted)
 
-    @only_initialized
     def set_volume(self, percent):
         self.video_params.volume = round(percent, 2)
 
@@ -534,6 +524,57 @@ class VideoBlock(QWidget):  # noqa: WPS230
 
         self.volume_change.emit(percent)
 
-    @only_initialized
     def play_pause(self):
         self.set_pause(not self.video_params.is_paused)
+
+    def previous_video(self):
+        # Stop new commands
+        self.video_driver.is_video_initialized = False
+
+        self.switch_video(next_video_file(self.video_params.file_path, is_before=True))
+
+    def next_video(self):
+        # Stop new commands
+        self.video_driver.is_video_initialized = False
+
+        self.switch_video(next_video_file(self.video_params.file_path))
+
+    def shuffle_video(self):
+        # Stop new commands
+        self.video_driver.is_video_initialized = False
+
+        self.switch_video(next_video_file(self.video_params.file_path, is_shuffle=True))
+
+    def switch_video(self, new_video):
+        # If single file in the dir and was removed, highly unlikely but still
+        if new_video is None:
+            self.cleanup()
+            self.error()
+            return
+
+        if new_video == self.video_params.file_path:
+            self.video_driver.is_video_initialized = True
+            self.seek(self.loop_start)
+            return
+
+        self.reset_loop()
+        self.video_params.current_position = 0
+        self.video_params.file_path = new_video
+        self.video_params.is_paused = False
+
+        self.set_video(self.video_params)
+
+    def rename(self):
+        new_name, new_color = QVideoRenameDialog.get_edits(
+            self.parent(),
+            self.tr("Rename video"),
+            self.video_params.file_path.name,
+            self.video_params.title,
+            self.video_params.color.as_rgb_tuple(),
+        )
+
+        self.video_params.title = new_name
+        self.video_params.color = Color(new_color)
+
+        self.label_change.emit(self.video_params.title)
+        self.color_change.emit(self.video_params.color.as_hex())
